# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/00-module.ipynb (unless otherwise specified).

__all__ = ['hello', 'hi']

# Cell

def hello():
    return 'hello world'

# Cell

def hi():
    return 'hi'